from django.test import TestCase

from django_freezer.admin import _parse

REQS_WITH_VERSIONS = """Django==1.6
ipdb==0.8
ipython==3.0.0
"""

REQS_WITHOUT_VERSIONS = """Django
ipdb
ipython
"""


class ParseTestCase(TestCase):

    def test_not_a_proper_string(self):
        not_reqs = 'This is just a text, plain text.'
        self.assertEquals(_parse(not_reqs), [[not_reqs]])

    def test_empty_string(self):
        self.assertEquals(_parse(''), [])

    def test_reqs_list_with_versions(self):
        self.assertEquals(_parse(REQS_WITH_VERSIONS),
                          [['Django', '1.6'],
                           ['ipdb', '0.8'],
                           ['ipython', '3.0.0']])

    def test_reqs_list_without_versions(self):
        self.assertEquals(_parse(REQS_WITHOUT_VERSIONS),
                          [['Django'],
                           ['ipdb'],
                           ['ipython']])



INSTALLED_APPS = (
    'django.contrib.sessions',
    'django.contrib.contenttypes',
    'django.contrib.messages',
    'django.contrib.auth',
    'django.contrib.admin',
    'django_freezer',
    'django_nose'
)

TEST_RUNNER = 'django_nose.NoseTestSuiteRunner'

SECRET_KEY = 'djangofreezer'

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': 'test.db',
    },
}

MIDDLEWARE_CLASSES = ()



#  -*- coding: utf-8 -*-
import django_freezer

try:
    from setuptools import setup
except ImportError:
    from ez_setup import use_setuptools
    use_setuptools()
    from setuptools import setup


setup(
    name='django-freezer',
    version=django_freezer.__version__,
    description='Print pip freeze in your admin panel',
    long_description=open('README.rst').read(),
    author='Michal Klich',
    author_email='michal@michalklich.com',
    include_package_data=True,
    packages=['django_freezer'],
    url='https://github.com/inirudebwoy/django-freezer',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'Framework :: Django',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ]
)



from subprocess import check_output, CalledProcessError

from django.contrib.admin import AdminSite


def _parse(reqs_str):
    """ Parse string of requirements into list """
    return [r.split('==') for r in reqs_str.splitlines()]


class FreezerAdminSite(object):
    index_template = 'djangofreezer/index.html'

    def index(self, request, extra_context=None):
        """ Add pip freeze info to request """
        if extra_context is None:
            extra_context = {}
        try:
            reqs = check_output(['pip', 'freeze'])
        except CalledProcessError:
            # attach error?
            reqs = 'pip freeze call failed'
        extra_context['requirements'] = _parse(reqs)
        return super(FreezerAdminSite, self).index(request, extra_context)


class AdminSiteExtended(FreezerAdminSite, AdminSite):
    """ Admin extended with pip freeze results """
